<?php

require_once __DIR__ . '/modele.inc.php';

function verifLogin($log, $mdp) {
    try {

        // connexion à la base de données
        $bdd = connexionBdd();
        $requete = $bdd->prepare("select id from joueurs where pseudo=:log and mdp=:mdp; ");
        $requete->bindParam(":log", $log);
        $requete->bindParam(":mdp", $mdp);
        $requete->execute();
        $retour = "bad log/pass";
        $nb = $requete->rowCount();

        if ($nb == 1) {
            $_SESSION['user'] = $log;
            $_SESSION['idUser'] = $requete->fetchColumn();
            if ($log != "admin") {
                $retour = "user";
            } else {
                $retour = "admin";
            }
        } else {
            if (isset($_SESSION['user'])) {
                unset($_SESSION['user']);
                unset($_SESSION['idUser']);
            }
        }

        return $retour;
    } catch (PDOException $e) {
        print "Erreur !: " . $e->getMessage() . "<br/>";
        die();
    }
}

function inscription($log, $mdp) {
    try {
        // connexion à la base de données
        $bdd = connexionBdd();

        // vérifier si le pseudo existe déjà
        $requete = $bdd->prepare("SELECT id FROM joueurs WHERE pseudo = :log;");
        $requete->bindParam(":log", $log);
        $requete->execute();
        $retour = "admin";
        if ($requete->rowCount() > 0) {
            $retour = "existe";
            if (isset($_SESSION['user'])) {
                unset($_SESSION['user']);
                unset($_SESSION['idUser']);
            }
        } else {
            $_SESSION['user'] = $log;

            if ($log != "admin") {
                $retour = "user";
            }
        }

        // insérer le nouveau joueur
        $insert = $bdd->prepare("INSERT INTO joueurs (pseudo, mdp) VALUES (:log, :mdp);");
        $insert->bindParam(":log", $log);
        $insert->bindParam(":mdp", $mdp);
        $insert->execute();
        $_SESSION['idUser'] = $bdd->lastInsertId();
        return $retour;
    } catch (PDOException $e) {
        print "Erreur !: " . $e->getMessage() . "<br/>";
        die();
    }
}

function majScore($score, $idCat) {
    try {
        // connexion à la base de données
        $bdd = connexionBdd();

        $idJoueur = $_SESSION['idUser'];

        // insérer le nouveau joueur
        $insert = $bdd->prepare("INSERT INTO scores (id_type,id_joueur,score,horodatage) VALUES (:cat, :user,:score,now());");
        $insert->bindParam(":cat", $idCat);
        $insert->bindParam(":user", $idJoueur);
        $insert->bindParam(":score", $score);
        $insert->execute();

        return "ok";
    } catch (PDOException $e) {
        print "Erreur !: " . $e->getMessage() . "<br/>";
        die();
    }
}

function getClassement($idCategorie = 0) {
    try {
        $connexion = connexionBdd(); // Connexion PDO déjà définie

        if ($idCategorie == 0) {
            $sql = "SELECT j.pseudo, t.nom_type, 
                           COUNT(*) AS nb_parties,
                           SUM(s.score) AS score_total, 
                           MAX(s.horodatage) AS horodatage
                    FROM scores s
                    JOIN joueurs j ON s.id_joueur = j.id
                    JOIN type_questions t ON s.id_type = t.id
                    GROUP BY j.pseudo, t.nom_type
                    ORDER BY score_total DESC, horodatage DESC
                    LIMIT 50";
            $stmt = $connexion->query($sql);
        } else {
            $sql = "SELECT j.pseudo, t.nom_type, 
                           COUNT(*) AS nb_parties,
                           SUM(s.score) AS score_total, 
                           MAX(s.horodatage) AS horodatage
                    FROM scores s
                    JOIN joueurs j ON s.id_joueur = j.id
                    JOIN type_questions t ON s.id_type = t.id
                    WHERE s.id_type = :id
                    GROUP BY j.pseudo, t.nom_type
                    ORDER BY score_total DESC, horodatage DESC
                    LIMIT 50";
            $stmt = $connexion->prepare($sql);
            $stmt->bindParam(':id', $idCategorie, PDO::PARAM_INT);
            $stmt->execute();
        }

        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        return [['erreur' => 'Erreur DB: ' . $e->getMessage()]];
    }
}

/* * *********************** */

function getMeilleursScoresParCategorie() {
    try {
        $connexion = connexionBdd();

        $sql = "SELECT t.nom_type, j.pseudo, SUM(s.score) AS score_total
                FROM scores s
                JOIN joueurs j ON s.id_joueur = j.id
                JOIN type_questions t ON s.id_type = t.id
                GROUP BY t.nom_type, j.pseudo
                ORDER BY t.nom_type, score_total DESC";
        $stmt = $connexion->query($sql);
        $result = $stmt->fetchAll(PDO::FETCH_ASSOC);

        $classementParCategorie = [];
        foreach ($result as $row) {
            $classementParCategorie[$row['nom_type']][] = $row;
        }

        return $classementParCategorie;
    } catch (PDOException $e) {
        return [['erreur' => 'Erreur DB: ' . $e->getMessage()]];
    }
}
